summaryrefslogtreecommitdiff
path: root/sw/source/core/graphic
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2017-02-13 17:05:19 +0100
committerMiklos Vajna <vmiklos@collabora.co.uk>2017-02-13 16:54:04 +0000
commit6657d52417295265367cf3ffe5832b60e3c38011 (patch)
treea664018f1eb611c88d8d73fd3b0241090ec36f8d /sw/source/core/graphic
parent7c9c6a4425b679596acae6f67ee8ac5f3d98bd6e (diff)
vcl pdf import: use pdfium instead of draw_pdf_import
Replace creating a full Draw component with direct pdfium library calls. This also means that the result is now a bitmap, not a metafile for now. Also decouple HAVE_FEATURE_PDFIMPORT and HAVE_FEATURE_PDFIUM, the first is the "import PDF into Draw" feature, the second is the "insert PDF as image" feature. Change-Id: I72c25642ec84cc831df362e02b1520c6e6d9adcf Reviewed-on: https://gerrit.libreoffice.org/34217 Reviewed-by: Miklos Vajna <vmiklos@collabora.co.uk> Tested-by: Jenkins <ci@libreoffice.org>
Diffstat (limited to 'sw/source/core/graphic')
-rw-r--r--sw/source/core/graphic/ndgrf.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/core/graphic/ndgrf.cxx b/sw/source/core/graphic/ndgrf.cxx
index 13a1f87d6134..e5b2ace6af87 100644
--- a/sw/source/core/graphic/ndgrf.cxx
+++ b/sw/source/core/graphic/ndgrf.cxx
@@ -401,8 +401,8 @@ const GraphicObject* SwGrfNode::GetReplacementGrfObj() const
const_cast< SwGrfNode* >(this)->mpReplacementGraphic = new GraphicObject(rSvgDataPtr->getReplacement());
}
else if (GetGrfObj().GetGraphic().getPdfData().hasElements())
- // This returns the metafile, without the pdf data.
- const_cast<SwGrfNode*>(this)->mpReplacementGraphic = new GraphicObject(GetGrfObj().GetGraphic().GetGDIMetaFile());
+ // This returns the bitmap, without the pdf data.
+ const_cast<SwGrfNode*>(this)->mpReplacementGraphic = new GraphicObject(GetGrfObj().GetGraphic().GetBitmapEx());
}
return mpReplacementGraphic;